@@ -4,7 +4,6 @@
 
 package Devel::SharedLibs;
 use v5.22;
-use autodie qw( open close );
 
 use IO::File;
 
@@ -14,11 +13,30 @@ use List::MoreUtils qw( uniq );
 # package variables
 ########################################################################
 
-our $VERSION = 'v0.3.1';
+our $VERSION = 'v0.3.2';
 $VERSION    = eval "$VERSION";
 
 sub import
 {
+    state $usable_ldd
+    = do
+    {
+$DB::single = 1;
+
+        # Aside: Need to check whether ldd on BSD, etc, supports
+        # long option for version.
+
+        my $result  = qx{ ldd --version 2>&1 };
+
+        my $success = ! $?
+        or warn <<"END";
+# Non-zeo exit: ldd --version ($result)
+# SharedLibs unable to generate output.
+END
+
+        $success
+    };
+
     # all this does it localize $path for the END closure.
     # kwikhak for the moment until I find out if there is 
     # any decent way to deal with ldd on BSD.
@@ -27,70 +45,83 @@ sub import
 
     END
     {
+$DB::single = 1;
+
         $ENV{ DEVEL_SHAREDLIBS_PRINT }
         or return;
 
-        $path   ||= $ENV{ DEVEL_SHAREDLIBS_PATH };
+        $path   ||= $ENV{ DEVEL_SHAREDLIBS_PATH }
+        or say "# False path & DEVEL_SHAREDLIBS_PATH: output to stdout.";
 
         # avoid stale output.
+        # if ldd is not usable then this leaves nothing behind.
+
+        my $continue    = $usable_ldd;
 
         if( $path && -e $path )
         {
+            say "# Remove stale: '$path'";
+
             unlink $path
             or do
             {
-                say STDERR
-                "Failed unlink: '$path', aborting";
-                exit -1;
+                warn <<"END";
+# Failed unlink: '$path', no SharedLibs output.
+# SharedLibs unable to generate output.
+END
+
+                $continue   = ''
             };
         }
 
-        qx{ ldd --version };
-
-        if( $? )
+        if( $continue )
         {
-            say STDERR
-            "Non-zeo exit: ldd --version ($?), no ouptut produced.";
+            use autodie qw( open close );
 
-            exit $?
+            local $,    = "\n";
+            local $\    = "\n";
+
+            my $fh
+            = $path
+            ? IO::File->new( $path, 'w' )
+            : *STDOUT{ IO }
+            ;
+
+            # sort isn't necessary for uniqueness but helps 
+            # by giving a stable output.
+
+            print $fh
+            "# ldd '$^X', '$0'" =>
+            sort { $a cmp $b }
+            uniq
+            map
+            {
+                # the literal '=>' dodges linux-vdso & friends,
+                # which lack a path and also the 
+                # "not a dynamic executable" messages from 
+                # most of the contents.
+
+                my ( $lib ) = m{ => \s+ (\S+) }x;
+
+                $lib || ()
+            }
+            map
+            {
+                split "\n" => qx(ldd $_ 2>/dev/null ) 
+            }
+            (
+                $^X,
+                values %INC
+            );
+
+            close $fh;
+
+            say STDERR "SharedLibs output: '$path'";
         }
-
-        local $,    = "\n";
-        local $\    = "\n";
-
-        my $fh
-        = $path
-        ? IO::File->new( $path, 'w' )
-        : *STDOUT{ IO }
-        ;
-
-        print $fh
-        "# ldd '$^X', '$0'" =>
-        uniq
-        sort
-        map
+        else
         {
-            # the literal '=>' dodges linux-vdso & friends,
-            # which lack a path and also the 
-            # "not a dynamic executable" messages from 
-            # most of the contents.
-
-            my ( $lib ) = m{ => \s+ (\S+) }x;
-
-            $lib || ()
+            say STDERR "SharedLibs unable to generate output."
         }
-        map
-        {
-            split "\n" => qx(ldd $_ 2>/dev/null ) 
-        }
-        (
-            $^X,
-            values %INC
-        );
-
-        close $fh;
-
-        say STDERR "SharedLibs output: '$path'";
     }
 }
 
